import os

from tencentcloud.common import credential
from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.cvm.v20170312 import cvm_client, models

from tencentcloud.common.profile.client_profile import ClientProfile
from tencentcloud.common.profile.http_profile import HttpProfile

class TencentDriver():
    
    def __init__(self, key, secret, region):
        cred = credential.Credential(key,secret)
        
        httpProfile = HttpProfile()
        httpProfile.reqMethod = "GET"  
        httpProfile.reqTimeout = 30    
        httpProfile.endpoint = "cvm." + region + ".tencentcloudapi.com" if region else "cvm.tencentcloudapi.com"
      
        clientProfile = ClientProfile()
        clientProfile.signMethod = "TC3-HMAC-SHA256" 
        clientProfile.language = "en-US"
        clientProfile.httpProfile = httpProfile

        self.client = cvm_client.CvmClient(cred, region, clientProfile)

    def list_regions(self):
        try:
            req = models.DescribeRegionsRequest()
            resp = self.client.DescribeRegions(req)
 
            return resp.RegionSet

        except TencentCloudSDKException as err:
            print(err)

    def list_nodes(self):
        try:
            req = models.DescribeInstancesRequest()
            resp = self.client.DescribeInstances(req)

            return resp.InstanceSet

        except TencentCloudSDKException as err:
            print(err)


    def destroy_node(self, node):
        try:
            req = models.TerminateInstancesRequest()
            req.InstanceIds = [node.InstanceId]

            resp = self.client.TerminateInstances(req)

        except TencentCloudSDKException as err:
            print(err)

    def stop_node(self, node):
        try:
            req = models.StopInstancesRequest()
            req.InstanceIds = [node.InstanceId]

            resp = self.client.StopInstances(req)

        except TencentCloudSDKException as err:
            print(err)

